'''OpenGL extension EXT.texture_env_combine

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_env_combine to provide a more 
Python-friendly API

Overview (from the spec)
	
	New texture environment function COMBINE_EXT allows programmable
	texture combiner operations, including:
	
	    REPLACE                 Arg0
	    MODULATE                Arg0 * Arg1
	    ADD                     Arg0 + Arg1
	    ADD_SIGNED_EXT          Arg0 + Arg1 - 0.5
	    INTERPOLATE_EXT         Arg0 * (Arg2) + Arg1 * (1-Arg2)
	
	where Arg0, Arg1 and Arg2 are derived from
	
	    PRIMARY_COLOR_EXT       primary color of incoming fragment
	    TEXTURE                 texture color of corresponding texture unit
	    CONSTANT_EXT            texture environment constant color
	    PREVIOUS_EXT            result of previous texture environment; on
	                            texture unit 0, this maps to PRIMARY_COLOR_EXT
	
	and Arg2 is restricted to the alpha component of the corresponding source.
	
	In addition, the result may be scaled by 1.0, 2.0 or 4.0.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_env_combine.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_env_combine import *
from OpenGL.raw.GL.EXT.texture_env_combine import _EXTENSION_NAME

def glInitTextureEnvCombineEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGI.texture_color_table

This module customises the behaviour of the 
OpenGL.raw.GL.SGI.texture_color_table to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a color lookup table to the texture mechanism.
	The table is applied to the filtered result of a texture lookup,
	before that result is used in the texture environment equations.
	
	The definition and application of the texture color table are
	similar to those of the color tables defined in SGI_color_table,
	though it is not necessary for that extension to be implemented.
	
	Texture color tables can be used to expand luminance or intensity
	textures to full RGBA, and also to linearize the results of color
	space conversions implemented by multidimensional texture table
	lookup.
	
	This specification has been updated to define its interaction with
	multitexture.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGI/texture_color_table.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGI.texture_color_table import *
from OpenGL.raw.GL.SGI.texture_color_table import _EXTENSION_NAME

def glInitTextureColorTableSGI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.vertex_array_range

This module customises the behaviour of the 
OpenGL.raw.WGL.NV.vertex_array_range to provide a more 
Python-friendly API

Overview (from the spec)
	
	The goal of this extension is to permit extremely high vertex
	processing rates via OpenGL vertex arrays even when the CPU lacks
	the necessary data movement bandwidth to keep up with the rate
	at which the vertex engine can consume vertices.  CPUs can keep
	up if they can just pass vertex indices to the hardware and
	let the hardware "pull" the actual vertex data via Direct Memory
	Access (DMA).  Unfortunately, the current OpenGL 1.1 vertex array
	functionality has semantic constraints that make such an approach
	hard.  Hence, the vertex array range extension.
	
	This extension provides a mechanism for deferring the pulling of
	vertex array elements to facilitate DMAed pulling of vertices for
	fast, efficient vertex array transfers.  The OpenGL client need only
	pass vertex indices to the hardware which can DMA the actual index's
	vertex data directly out of the client address space.
	
	The OpenGL 1.1 vertex array functionality specifies a fairly strict
	coherency model for when OpenGL extracts vertex data from a vertex
	array and when the application can update the in memory
	vertex array data.  The OpenGL 1.1 specification says "Changes
	made to array data between the execution of Begin and the
	corresponding execution of End may affect calls to ArrayElement
	that are made within the same Begin/End period in non-sequential
	ways.  That is, a call to ArrayElement that precedes a change to
	array data may access the changed data, and a call that follows
	a change to array data may access the original data."
	
	This means that by the time End returns (and DrawArrays and
	DrawElements return since they have implicit Ends), the actual vertex
	array data must be transferred to OpenGL.  This strict coherency model
	prevents us from simply passing vertex element indices to the hardware
	and having the hardware "pull" the vertex data out (which is often
	long after the End for the primitive has returned to the application).
	
	Relaxing this coherency model and bounding the range from which
	vertex array data can be pulled is key to making OpenGL vertex
	array transfers faster and more efficient.
	
	The first task of the vertex array range extension is to relax
	the coherency model so that hardware can indeed "pull" vertex
	data from the OpenGL client's address space long after the application
	has completed sending the geometry primitives requiring the vertex
	data.
	
	The second problem with the OpenGL 1.1 vertex array functionality is
	the lack of any guidance from the API about what region of memory
	vertices can be pulled from.  There is no size limit for OpenGL 1.1
	vertex arrays.  Any vertex index that points to valid data in all
	enabled arrays is fair game.  This makes it hard for a vertex DMA
	engine to pull vertices since they can be potentially pulled from
	anywhere in the OpenGL client address space.
	
	The vertex array range extension specifies a range of the OpenGL
	client's address space where vertices can be pulled.  Vertex indices
	that access any array elements outside the vertex array range
	are specified to be undefined.  This permits hardware to DMA from
	finite regions of OpenGL client address space, making DMA engine
	implementation tractable.
	
	The extension is specified such that an (error free) OpenGL client
	using the vertex array range functionality could no-op its vertex
	array range commands and operate equivalently to using (if slower
	than) the vertex array range functionality.
	
	Because different memory types (local graphics memory, AGP memory)
	have different DMA bandwidths and caching behavior, this extension
	includes a window system dependent memory allocator to allocate
	cleanly the most appropriate memory for constructing a vertex array
	range.  The memory allocator provided allows the application to
	tradeoff the desired CPU read frequency, CPU write frequency, and
	memory priority while still leaving it up to OpenGL implementation
	the exact memory type to be allocated.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/vertex_array_range.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.NV.vertex_array_range import *
from OpenGL.raw.WGL.NV.vertex_array_range import _EXTENSION_NAME

def glInitVertexArrayRangeNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.float_pixels

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.float_pixels to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extensions adds texture types, texture internal formats and
	color buffers composed of both 32 bit and 16 floating point numbers.
	 16 bit floats (half float) are very similar to the IEEE
	single-precision floating-point standard, except that it has only 5
	exponent bits and 10 mantissa bits. All floating point numbers are
	clamped to the limits of the range representable by their respective
	format.
	
	Specifically, APPLE_float_pixels adds four pieces of functionality
	to OpenGL.  First, it provides an HALF_APPLE texture type allowing
	clients to pass textures in the half float format.  Second, it adds
	12 additional sized internal formats to allow OpenGL to process and
	maintain texture data in the requested format if possible.  Next, it
	provides the COLOR_FLOAT_APPLE pixel format to allow creation of
	floating point and half float color buffers. Lastly, it provides an
	additional query to allow clients to verify that they have a
	floating point color buffer.
	
	The HALF_APPLE texture type allows clients to use source textures
	composed of half float color components.  This constant is use in
	the type parameter in DrawPixels, ReadPixels and texturing commands
	with a corresponding GL half data type, which corresponds to a 16
	bit half float, and has no special interpretation.
	
	Clients can use the 12 additional (6 floating point and 6 half
	float) sized internal texture formats to specify the mapping of R,
	G, B and A values to texture components, as they would with any
	other sized internal texture format.  Note, as is the standard
	practice with OpenGL, implementations should map the sized internal
	texture R, G, B and A values to internal components with memory
	allocations as close as possible to those specified in the sized
	internal format.
	
	Floating point color buffers are created by specifying the
	appropriate color floating point pixel format attribute for the
	windowing system API in use by the client.  Both 128 bit and 64 bit
	floating point color buffers can be supported, the former with full
	32 bit floating point components and the latter with 16 bit half
	float components.
	
	Additionally, clients can query to see if they have a floating point
	color buffer using GetBooleanv with COLOR_FLOAT_APPLE as the get
	value.  The number of bits per color buffer component can be
	determined in the usual manner.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/float_pixels.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.float_pixels import *
from OpenGL.raw.GL.APPLE.float_pixels import _EXTENSION_NAME

def glInitFloatPixelsAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.texture_shader

This module customises the behaviour of the 
OpenGL.raw.GL.NV.texture_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	Standard OpenGL and the ARB_multitexture extension define a
	straightforward direct mechanism for mapping sets of texture
	coordinates to filtered colors.  This extension provides a more
	functional mechanism.
	
	OpenGL's standard texturing mechanism defines a set of texture
	targets.  Each texture target defines how the texture image
	is specified and accessed via a set of texture coordinates.
	OpenGL 1.0 defines the 1D and 2D texture targets.  OpenGL 1.2
	(and/or the EXT_texture3D extension) defines the 3D texture target.
	The ARB_texture_cube_map extension defines the cube map texture
	target.  Each texture unit's texture coordinate set is mapped to a
	color using the unit's highest priority enabled texture target.
	
	This extension introduces texture shader stages.  A sequence of
	texture shader stages provides a more flexible mechanism for mapping
	sets of texture coordinates to texture unit RGBA results than standard
	OpenGL.
	
	When the texture shader enable is on, the extension replaces the
	conventional OpenGL mechanism for mapping sets of texture coordinates
	to filtered colors with this extension's sequence of texture shader
	stages.  
	
	Each texture shader stage runs one of 21 canned texture shader
	programs.  These programs support conventional OpenGL texture
	mapping but also support dependent texture accesses, dot product
	texture programs, and special modes.  (3D texture mapping
	texture shader operations are NOT provided by this extension;
	3D texture mapping texture shader operations are added by the
	NV_texture_shader2 extension that is layered on this extension.
	See the NV_texture_shader2 specification.)
	
	To facilitate the new texture shader programs, this extension
	introduces several new texture formats and variations on existing
	formats.  Existing color texture formats are extended by introducing
	new signed variants.  Two new types of texture formats (beyond colors)
	are also introduced.  Texture offset groups encode two signed offsets,
	and optionally a magnitude or a magnitude and an intensity.  The new
	HILO (pronounced high-low) formats provide possibly signed, high
	precision (16-bit) two-component textures.
	
	Each program takes as input the stage's interpolated texture
	coordinate set (s,t,r,q).  Each program generates two results:
	a shader stage result that may be used as an input to subsequent
	shader stage programs, and a texture unit RGBA result that becomes the
	texture color used by the texture unit's texture environment function
	or becomes the initial value for the corresponding texture register
	for register combiners. The texture unit RGBA result is always
	an RGBA color, but the shader stage result may be one of an RGBA
	color, a HILO value, a texture offset group, a floating-point value,
	or an invalid result.  When both results are RGBA colors, the shader
	stage result and the texture unit RGBA result are usually identical
	(though not in all cases).
	
	Additionally, certain programs have a side-effect such as culling
	the fragment or replacing the fragment's depth value.
	
	The twenty-one programs are briefly described:
	
	<none>
	
	1.   NONE - Always generates a (0,0,0,0) texture unit RGBA result.
	     Equivalent to disabling all texture targets in conventional
	     OpenGL.
	
	<conventional textures>
	
	2.   TEXTURE_1D - Accesses a 1D texture via (s/q).
	
	3.   TEXTURE_2D - Accesses a 2D texture via (s/q,t/q).
	
	4.   TEXTURE_RECTANGLE_NV - Accesses a rectangular texture via (s/q,t/q).
	
	5.   TEXTURE_CUBE_MAP_ARB - Accesses a cube map texture via (s,t,r).
	
	<special modes>
	
	6.   PASS_THROUGH_NV - Converts a texture coordinate (s,t,r,q)
	     directly to a [0,1] clamped (r,g,b,a) texture unit RGBA result.
	
	7.   CULL_FRAGMENT_NV - Culls the fragment based on the whether each
	     (s,t,r,q) is "greater than or equal to zero" or "less than zero".
	
	<offset textures>
	
	8.   OFFSET_TEXTURE_2D_NV - Transforms the signed (ds,dt) components
	     of a previous texture unit by a 2x2 floating-point matrix and
	     then uses the result to offset the stage's texture coordinates
	     for a 2D non-projective texture.
	
	9.   OFFSET_TEXTURE_2D_SCALE_NV - Same as above except the magnitude
	     component of the previous texture unit result scales the red,
	     green, and blue components of the unsigned RGBA texture 2D
	     access.
	
	10.  OFFSET_TEXTURE_RECTANGLE_NV - Similar to OFFSET_TEXTURE_2D_NV
	     except that the texture access is into a rectangular
	     non-projective texture.
	
	11.  OFFSET_TEXTURE_RECTANGLE_SCALE_NV - Similar to
	     OFFSET_TEXTURE_2D_SCALE_NV except that the texture access is
	     into a rectangular non-projective texture.
	
	<dependent textures>
	
	12.  DEPENDENT_AR_TEXTURE_2D_NV - Converts the alpha and red
	     components of a previous shader result into an (s,t) texture
	     coordinate set to access a 2D non-projective texture.
	
	13.  DEPENDENT_GB_TEXTURE_2D_NV - Converts the green and blue
	     components of a previous shader result into an (s,t) texture
	     coordinate set to access a 2D non-projective texture.
	
	<dot product textures>
	
	14.  DOT_PRODUCT_NV - Computes the dot product of the texture
	     shader's texture coordinate set (s,t,r) with some mapping of the
	     components of a previous texture shader result.  The component
	     mapping depends on the type (RGBA or HILO) and signedness of
	     the stage's previous texture input.  Other dot product texture
	     programs use the result of this program to compose a texture
	     coordinate set for a dependent texture access.  The color result
	     is undefined.
	
	15.  DOT_PRODUCT_TEXTURE_2D_NV - When preceded by a DOT_PRODUCT_NV
	     program in the previous texture shader stage, computes a second
	     similar dot product and composes the two dot products into (s,t)
	     texture coordinate set to access a 2D non-projective texture.
	
	16.  DOT_PRODUCT_TEXTURE_RECTANGLE_NV - Similar to
	     DOT_PRODUCT_TEXTURE_2D_NV except that the texture acces is into
	     a rectangular non-projective texture.  
	
	17.  DOT_PRODUCT_TEXTURE_CUBE_MAP_NV - When preceded by two
	     DOT_PRODUCT_NV programs in the previous two texture shader
	     stages, computes a third similar dot product and composes the
	     three dot products into (s,t,r) texture coordinate set to access
	     a cube map texture.
	
	18.  DOT_PRODUCT_REFLECT_CUBE_MAP_NV - When preceded by two
	     DOT_PRODUCT_NV programs in the previous two texture shader
	     stages, computes a third similar dot product and composes the
	     three dot products into a normal vector (Nx,Ny,Nz).  An eye
	     vector (Ex,Ey,Ez) is composed from the q texture coordinates of
	     the three stages.  A reflection vector (Rx,Ry,Rz) is computed
	     based on the normal and eye vectors.  The reflection vector
	     forms an (s,t,r) texture coordinate set to access a cube map
	     texture.
	
	19.  DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV - Operates like
	     DOT_PRODUCT_REFLECT_CUBE_MAP_NV except that the eye vector
	     (Ex,Ey,Ez) is a user-defined constant rather than composed from
	     the q coordinates of the three stages.
	
	20.  DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV - When used instead of the second
	     DOT_PRODUCT_NV program preceding
	     a DOT_PRODUCT_REFLECT_CUBE_MAP_NV or
	     DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV stage, the normal
	     vector forms an (s,t,r) texture  coordinate set to access a
	     cube map texture.
	
	<dot product depth replace>
	
	21.  DOT_PRODUCT_DEPTH_REPLACE_NV - When preceded by a DOT_PRODUCT_NV
	     program in the previous texture shader stage, computes a second
	     similar dot product and replaces the fragment's window-space
	     depth value with the first dot product results divided by
	     the second.  The texture unit RGBA result is (0,0,0,0).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/texture_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.texture_shader import *
from OpenGL.raw.GL.NV.texture_shader import _EXTENSION_NAME

def glInitTextureShaderNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
GL_OFFSET_TEXTURE_2D_BIAS_NV = GL_OFFSET_TEXTURE_BIAS_NV # alias
GL_OFFSET_TEXTURE_2D_MATRIX_NV = GL_OFFSET_TEXTURE_MATRIX_NV # alias
GL_OFFSET_TEXTURE_2D_SCALE_NV = GL_OFFSET_TEXTURE_SCALE_NV # alias



'''OpenGL extension EXT.vertex_weighting

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.vertex_weighting to provide a more 
Python-friendly API

Overview (from the spec)
	
	The intent of this extension is to provide a means for blending
	geometry based on two slightly differing modelview matrices.
	The blending is based on a vertex weighting that can change on a
	per-vertex basis.  This provides a primitive form of skinning.
	
	A second modelview matrix transform is introduced.  When vertex
	weighting is enabled, the incoming vertex object coordinates are
	transformed by both the primary and secondary modelview matrices;
	likewise, the incoming normal coordinates are transformed by the
	inverses of both the primary and secondary modelview matrices.
	The resulting two position coordinates and two normal coordinates
	are blended based on the per-vertex vertex weight and then combined
	by addition.  The transformed, weighted, and combined vertex position
	and normal are then used by OpenGL as the eye-space position and
	normal for lighting, texture coordinate, generation, clipping,
	and further vertex transformation.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/vertex_weighting.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.vertex_weighting import *
from OpenGL.raw.GL.EXT.vertex_weighting import _EXTENSION_NAME

def glInitVertexWeightingEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glVertexWeightfvEXT=wrapper.wrapper(glVertexWeightfvEXT).setInputArraySize(
    'weight', 1
)
# INPUT glVertexWeightPointerEXT.pointer size not checked against 'type,stride'
glVertexWeightPointerEXT=wrapper.wrapper(glVertexWeightPointerEXT).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension ATI.fragment_shader

This module customises the behaviour of the 
OpenGL.raw.GL.ATI.fragment_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension exposes a powerful fragment shading model which
	provides a very general means of expressing fragment color blending
	and dependent texture address modification.  The programming is
	a register-based model in which there is a fixed number of 
	instructions, texture lookups, read/write registers, and constants.
	
	The fragment shader extension provides a unified instruction set
	for operating on address or color data and eliminates the 
	distinction between the two.  This extension provides all the 
	interfaces necessary to fully expose this programmable fragment 
	shader in GL.
	
	Although conceived as a device-independent extension which would 
	expose the capabilities of future generations of hardware, changing 
	trends in programmable hardware have affected the lifespan of this 
	extension.  For this reason you will now find a fixed set of 
	features and resources exposed, and the queries to determine this 
	set have been deprecated.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ATI/fragment_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ATI.fragment_shader import *
from OpenGL.raw.GL.ATI.fragment_shader import _EXTENSION_NAME

def glInitFragmentShaderATI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glSetFragmentShaderConstantATI=wrapper.wrapper(glSetFragmentShaderConstantATI).setInputArraySize(
    'value', 4
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_SGIX_hyperpipe'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_SGIX_hyperpipe',error_checker=_errors._error_checker)
GLX_BAD_HYPERPIPE_CONFIG_SGIX=_C('GLX_BAD_HYPERPIPE_CONFIG_SGIX',91)
GLX_BAD_HYPERPIPE_SGIX=_C('GLX_BAD_HYPERPIPE_SGIX',92)
GLX_HYPERPIPE_DISPLAY_PIPE_SGIX=_C('GLX_HYPERPIPE_DISPLAY_PIPE_SGIX',0x00000001)
GLX_HYPERPIPE_ID_SGIX=_C('GLX_HYPERPIPE_ID_SGIX',0x8030)
GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX=_C('GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX',80)
GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX=_C('GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX',0x00000004)
GLX_HYPERPIPE_RENDER_PIPE_SGIX=_C('GLX_HYPERPIPE_RENDER_PIPE_SGIX',0x00000002)
GLX_HYPERPIPE_STEREO_SGIX=_C('GLX_HYPERPIPE_STEREO_SGIX',0x00000003)
GLX_PIPE_RECT_LIMITS_SGIX=_C('GLX_PIPE_RECT_LIMITS_SGIX',0x00000002)
GLX_PIPE_RECT_SGIX=_C('GLX_PIPE_RECT_SGIX',0x00000001)
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int)
def glXBindHyperpipeSGIX(dpy,hpId):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int)
def glXDestroyHyperpipeConfigSGIX(dpy,hpId):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,_cs.c_int,ctypes.c_void_p)
def glXHyperpipeAttribSGIX(dpy,timeSlice,attrib,size,attribList):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,ctypes.POINTER(_cs.GLXHyperpipeConfigSGIX),ctypes.POINTER(_cs.c_int))
def glXHyperpipeConfigSGIX(dpy,networkId,npipes,cfg,hpId):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,_cs.c_int,ctypes.c_void_p)
def glXQueryHyperpipeAttribSGIX(dpy,timeSlice,attrib,size,returnAttribList):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,_cs.c_int,ctypes.c_void_p,ctypes.c_void_p)
def glXQueryHyperpipeBestAttribSGIX(dpy,timeSlice,attrib,size,attribList,returnAttribList):pass
@_f
@_p.types(ctypes.POINTER(_cs.GLXHyperpipeConfigSGIX),ctypes.POINTER(_cs.Display),_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXQueryHyperpipeConfigSGIX(dpy,hpId,npipes):pass
@_f
@_p.types(ctypes.POINTER(_cs.GLXHyperpipeNetworkSGIX),ctypes.POINTER(_cs.Display),ctypes.POINTER(_cs.c_int))
def glXQueryHyperpipeNetworkSGIX(dpy,npipes):pass
